//+------------------------------------------------------------------+
//|                                             .mq4 |
//|                                           Copyright  2010, Alex |
//|                                                          http:// |
//+------------------------------------------------------------------+
#property copyright "Copyright  2010, Alex"
#property link      "http://"

#define MAGICMA  20050610

extern double Lots               = 0.1;
extern double MaximumRisk        = 0.02;
extern double DecreaseFactor     = 3;
extern double n      = 3.5;
extern double n2       = 1.5;
//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICMA)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=Lots;
   int    orders=HistoryTotal();     // history orders total
   int    losses=0;                  // number of losses orders without a break
//---- select lot size
   lot=NormalizeDouble(AccountFreeMargin()*MaximumRisk/1000.0,1);
//---- calcuulate number of losses orders without a break
   if(DecreaseFactor>0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==false) { Print("Error in history!"); break; }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL) continue;
         //----
         if(OrderProfit()>0) break;
         if(OrderProfit()<0) losses++;
        }
      if(losses>1) lot=NormalizeDouble(lot-lot*losses/DecreaseFactor,1);
     }
//---- return lot size
   if(lot<0.1) lot=0.1;
   return(lot);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {
   double ma, ma1;
   int    res, res2;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//---- get Moving Average 
   ma=MarketInfo("GOLD", MODE_BID);
   ma1=MarketInfo("ZG-Z10", MODE_BID);
//---- sell conditions
   if(ma1-ma<n2)  
     {
     
      res=OrderSend("GOLD",OP_SELL,0.1,NormalizeDouble(Bid, Digits),20,0,0," ",MAGICMA,0,Red);
      res2=OrderSend("ZG-Z10",OP_BUY,0.1,NormalizeDouble(MarketInfo("ZG-Z10",MODE_ASK), MarketInfo("ZG-Z10",MODE_DIGITS)),5,0,0," ",MAGICMA,0,Blue);
      return;
     }
//---- buy conditions
   if(ma1-ma>n)  
     {
     
      res=OrderSend("GOLD",OP_BUY,0.1,NormalizeDouble(Ask, Digits),20,0,0," ",MAGICMA,0,Blue);
      res2=OrderSend("ZG-Z10",OP_SELL,0.1,NormalizeDouble(MarketInfo("ZG-Z10",MODE_BID), MarketInfo("ZG-Z10",MODE_DIGITS)),5,0,0," ",MAGICMA,0,Red);
      return;
     }
//----
  }
//+------------------------------------------------------------------+
//| Check for close order conditions                                 |
//+------------------------------------------------------------------+
void CheckForClose()
  {
   double ma, ma1;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//---- get Moving Average 
   ma=MarketInfo("GOLD", MODE_BID);
   ma1=MarketInfo("ZG-Z10", MODE_BID);
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false)        break;
      if(OrderMagicNumber()!=MAGICMA || OrderSymbol()!="GOLD") continue;
      //---- check order type 
      if(OrderType()==OP_BUY)
        {
       
         if(ma1-ma<n2) OrderClose(OrderTicket(),OrderLots(),NormalizeDouble(Bid, Digits),20,White);
         break;
        }
      if(OrderType()==OP_SELL)
        {
         if(ma1-ma>n) OrderClose(OrderTicket(),OrderLots(),NormalizeDouble(Ask, Digits),20,White);
         break;
        }
     }
    for(i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false)        break;
      if(OrderMagicNumber()!=MAGICMA || OrderSymbol()!="ZG-Z10") continue;
      //---- check order type 
      if(OrderType()==OP_BUY)
        {
         if(ma1-ma>n) OrderClose(OrderTicket(),OrderLots(),NormalizeDouble(MarketInfo("ZG-Z10",MODE_BID), MarketInfo("ZG-Z10",MODE_DIGITS)),3,White);
         break;
        }
      if(OrderType()==OP_SELL)
        {
         if(ma1-ma<n2) OrderClose(OrderTicket(),OrderLots(),NormalizeDouble(MarketInfo("ZG-Z10",MODE_ASK), MarketInfo("ZG-Z10",MODE_DIGITS)),3,White);
         break;
        }
     }
//----
  }//----
  
//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  {
//---- check for history and trading
   
//---- calculate open orders by current symbol
   if(CalculateCurrentOrders(Symbol())==0) CheckForOpen();
   else                                    CheckForClose();
//----
  }
//+------------------------------------------------------------------+